Module graph_ptr

Module graph_ptr 

Modules

core_
The Rust Core Library

Macros

make_guard
Create a Guard with a unique invariant lifetime (with respect to other trusted/invariant lifetime brands).

Structs

GraphPtr
A checked pointer type used to access and traverse graph nodes in the crate. This pointer cannot be dereferenced and requires the parent anchor object to access the data stored in the collection.
Guard
An invariant lifetime phantomdata-alike that is guaranteed to be unique with respect to other trusted invariant lifetimes.
Id
A phantomdata-like type taking a single invariant lifetime.